<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<!--
SPDX-FileCopyrightText: 2002-2011 Joachim Eibl, joachim.eibl at gmx.de
SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
SPDX-License-Identifier: GPL-2.0-or-later
-->
<gui name="kdiff3_part" version="9">
<MenuBar>
  <Menu name="movement"><text>&amp;KDiff3</text>
    <Action name="go_top"/>
    <Action name="go_bottom"/>
    <Action name="go_prev_delta"/>
    <Action name="go_next_delta"/>
    <Action name="diff_showwhitespace"/>
    <Action name="diff_showlinenumbers"/>
    <Action name="diff_wordwrap"/>
    <Action name="win_toggle_split_orientation"/>
    <Action name="options_configure"><text>Configure KDiff3</text></Action>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>KDiff3</text>
  <Action name="go_top"/>
  <Action name="go_bottom"/>
  <Action name="go_prev_delta"/>
  <Action name="go_next_delta"/>
  <Action name="diff_showwhitespace"/>
  <Action name="diff_showlinenumbers"/>
</ToolBar>
</gui>
